Package: badpackage
Title: Advice on R package building
Date: 2016 February
Version: 1.0.0
Author: Gabor Csardi
Maintainer: Gabor Csardi <gcsardi@mango-solutions.com>
Description: Give advice about good practices when building R packages.
License: Public domain
Suggests:
    testthat
RoxygenNote: 5.0.1
biocViews: GraphAndNetwork
