Package: badpackage
Title: Advice on R package building
Date: 2016 February
Version: 1.0.0
Author: Gabor Csardi
Maintainer: Gabor Csardi <gcsardi@mango-solutions.com>
Description: Give advice about good practices when building R packages.
License: GPL
Suggests:
    testthat,
    knitr,
    rmarkdown,
    svglite
RoxygenNote: 6.1.0
Repository: CRAN
Encoding: UTF-8
VignetteBuilder: knitr
Config/build/clean-inst-doc: FALSE
