# Generated by roxygen2: do not edit by hand

S3method(as.data.frame,rcmdcheck)
S3method(print,rcmdcheck)
S3method(print,rcmdcheck_comparison)
S3method(print,rcmdcheck_comparison_summary)
S3method(summary,rcmdcheck)
S3method(summary,rcmdcheck_comparison)
S3method(xopen,rcmdcheck)
export(check_details)
export(compare_checks)
export(compare_to_cran)
export(cran_check_flavours)
export(cran_check_results)
export(parse_check)
export(parse_check_url)
export(rcmdcheck)
export(rcmdcheck_process)
importFrom(R6,R6Class)
importFrom(callr,rcmd_process)
importFrom(callr,rcmd_process_options)
importFrom(callr,rcmd_safe)
importFrom(cli,cli_progress_bar)
importFrom(cli,cli_progress_update)
importFrom(cli,is_dynamic_tty)
importFrom(cli,symbol)
importFrom(curl,handle_setopt)
importFrom(curl,multi_add)
importFrom(curl,multi_cancel)
importFrom(curl,multi_list)
importFrom(curl,multi_run)
importFrom(curl,new_handle)
importFrom(curl,new_pool)
importFrom(desc,desc)
importFrom(desc,description)
importFrom(digest,digest)
importFrom(pkgbuild,pkgbuild_process)
importFrom(prettyunits,pretty_dt)
importFrom(prettyunits,pretty_sec)
importFrom(rprojroot,find_package_root_file)
importFrom(utils,head)
importFrom(utils,tail)
importFrom(withr,local_path)
importFrom(withr,with_dir)
importFrom(withr,with_envvar)
importFrom(xopen,xopen)
