% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/package.R
\name{foobar2}
\alias{foobar2}
\title{foobar2}
\usage{
foobar2()
}
\description{
foobar2
}
\examples{
foobar2()
}
